import { ethers } from "ethers";
import * as solana from "@solana/web3.js";
import { ChainId, EVMChainId } from "@certusone/wormhole-sdk";
import * as sui from "@mysten/sui.js";
import { WalletToolBox } from "./walletToolBox.js";
import { Middleware } from "../../compose.middleware.js";
import { ProviderContext, UntypedProvider } from "../providers.middleware.js";
import { Logger } from "winston";
import { TokensByChain } from "./wallet-management.js";
import { Registry } from "prom-client";
import { Environment } from "../../environment.js";
import { DirectSecp256k1Wallet } from "@cosmjs/proto-signing";
export type EVMWallet = ethers.Wallet;
export type SuiWallet = sui.RawSigner;
export type SeiWallet = DirectSecp256k1Wallet;
export type SolanaWallet = {
    conn: solana.Connection;
    payer: solana.Keypair;
};
export type Wallet = EVMWallet | SolanaWallet | UntypedWallet | SuiWallet | SeiWallet;
export type UntypedWallet = UntypedProvider & {
    privateKey: string;
};
export interface Action<T, W extends Wallet> {
    chainId: ChainId;
    f: ActionFunc<T, W>;
}
export type ActionFunc<T, W extends Wallet> = (walletToolBox: WalletToolBox<W>, chaidId: ChainId) => Promise<T>;
export interface ActionWithCont<T, W extends Wallet> {
    action: Action<T, W>;
    pluginName: string;
    resolve: (t: T) => void;
    reject: (reason: any) => void;
}
export interface WorkerInfo {
    id: number;
    targetChainId: ChainId;
    targetChainName: string;
    walletPrivateKey: string;
}
export interface ActionExecutor {
    <T, W extends Wallet>(chaindId: ChainId, f: ActionFunc<T, W>): Promise<T>;
    onSolana<T>(f: ActionFunc<T, SolanaWallet>): Promise<T>;
    onEVM<T>(chainId: EVMChainId, f: ActionFunc<T, EVMWallet>): Promise<T>;
    onSei<T>(f: ActionFunc<T, SeiWallet>): Promise<T>;
    onSui<T>(f: ActionFunc<T, SuiWallet>): Promise<T>;
}
export interface WalletContext extends ProviderContext {
    wallets: ActionExecutor;
}
export interface WalletOpts {
    namespace: string;
    privateKeys: Partial<{
        [k in ChainId]: any[];
    }>;
    tokensByChain?: TokensByChain;
    logger?: Logger;
    metrics?: {
        enabled: boolean;
        registry: Registry;
    };
}
export declare function wallets(env: Environment, opts: WalletOpts): Middleware<WalletContext>;
