"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WormholescanClient = void 0;
const http_client_js_1 = require("./http-client.js");
/**
 * Client for the wormholescan API that never throws, but instead returns a WormholescanResult that may contain an error.
 */
class WormholescanClient {
    baseUrl;
    defaultOptions;
    client;
    constructor(baseUrl, defaultOptions) {
        this.baseUrl = baseUrl;
        this.defaultOptions = defaultOptions;
        this.client = new http_client_js_1.HttpClient({
            timeout: defaultOptions?.timeout,
            retries: defaultOptions?.retries,
            initialDelay: defaultOptions?.initialDelay,
            maxDelay: defaultOptions?.maxDelay,
            cache: defaultOptions?.noCache ? "no-cache" : "default",
        });
    }
    async listVaas(chain, emitterAddress, opts) {
        try {
            const response = await this.client.get(`${this.baseUrl}api/v1/vaas/${chain}/${emitterAddress}?page=${this.getPage(opts)}&pageSize=${this.getPageSize(opts)}`, opts);
            return {
                data: response.data.map(v => {
                    return {
                        ...v,
                        vaa: Buffer.from(v.vaa, "base64"),
                    };
                }),
            };
        }
        catch (err) {
            return { error: err, data: [] };
        }
    }
    async getVaa(chain, emitterAddress, sequence, opts) {
        try {
            const response = await this.client.get(`${this.baseUrl}api/v1/vaas/${chain}/${emitterAddress}/${sequence.toString()}`, opts);
            return {
                data: {
                    ...response.data,
                    vaa: Buffer.from(response.data.vaa, "base64"),
                },
            };
        }
        catch (err) {
            return this.mapError(err);
        }
    }
    async getTransaction(chain, emitterAddress, sequence, opts) {
        try {
            const response = await this.client.get(`${this.baseUrl}api/v1/transactions/${chain}/${emitterAddress}/${sequence.toString()}`, opts);
            return {
                data: response,
            };
        }
        catch (err) {
            return this.mapError(err);
        }
    }
    mapError(err) {
        if (err instanceof http_client_js_1.HttpClientError) {
            return { error: err };
        }
        return { error: new http_client_js_1.HttpClientError(err.message) };
    }
    getPage(opts) {
        return opts?.page ?? this.defaultOptions?.page ?? 0;
    }
    getPageSize(opts) {
        return opts?.pageSize ?? this.defaultOptions?.pageSize ?? 10;
    }
}
exports.WormholescanClient = WormholescanClient;
//# sourceMappingURL=wormholescan-client.js.map