import { CHAIN_ID_SOLANA, isEVMChain, } from "@certusone/wormhole-sdk";
export function legacyPluginCompat(app, plugin) {
    const filters = plugin.getFilters();
    const multiple = {};
    for (const { chainId, emitterAddress, doNotTransform } of filters) {
        if (multiple[chainId]?.length !== 0) {
            multiple[chainId] = [];
        }
        // todo: support doNotTransform option
        multiple[chainId]?.push(emitterAddress);
    }
    // plugin.afterSetup(providers, )
    app.multiple(multiple, async (ctx, next) => {
        const { kv, vaa, vaaBytes, logger } = ctx;
        const vaaWithBytes = vaa;
        vaaWithBytes.bytes = vaaBytes;
        const providers = providersShimToLegacy(ctx.providers);
        const res = await plugin.consumeEvent(vaaWithBytes, kv, Object.assign(providers));
        if (!res) {
            return next();
        }
        const { workflowOptions, workflowData } = res;
        await plugin.handleWorkflow({ data: workflowData }, providers, makeExecuteWrapper(ctx));
        return next();
    });
}
function makeExecuteWrapper(ctx) {
    const execute = async (action) => {
        if (isEVMChain(action.chainId)) {
            ctx.wallets.onEVM(action.chainId, (wallet, chainId) => {
                return action.f(walletShimToLegacy(wallet), chainId);
            });
        }
        else if (action.chainId === CHAIN_ID_SOLANA) {
            return ctx.wallets.onSolana((wallet) => action.f(walletShimToLegacy(wallet), action.chainId));
        }
    };
    execute.onEVM = (action) => {
        return ctx.wallets.onEVM(action.chainId, (wallet) => action.f(walletShimToLegacy(wallet), action.chainId));
    };
    execute.onSolana = (f) => {
        return ctx.wallets.onSolana(f);
    };
    execute.onSui = (f) => {
        return ctx.wallets.onSui(f);
    };
    return execute;
}
function providersShimToLegacy(providers) {
    return {
        solana: providers.solana.length > 0
            ? providers.solana[0]
            : undefined,
        untyped: Object.fromEntries(Object.entries(providers.untyped).map(([chain, rpcs]) => [
            chain,
            rpcs[0],
        ])),
        evm: Object.fromEntries(Object.entries(providers.evm).map(([chain, rpcs]) => [chain, rpcs[0]])),
        sui: providers.sui.length > 0
            ? providers.sui[0]
            : undefined,
        sei: providers.sei.length > 0
            ? providers.sei[0]
            : undefined,
    };
}
function providersShimFromLegacy(providers) {
    return {
        solana: providers.solana ? [providers.solana] : [],
        untyped: Object.fromEntries(Object.entries(providers.untyped).map(([chain, rpc]) => [chain, [rpc]])),
        evm: Object.fromEntries(Object.entries(providers.evm).map(([chain, rpc]) => [chain, [rpc]])),
        sui: providers.sui ? [providers.sui] : [],
        sei: providers.sei ? [providers.sei] : [],
    };
}
function walletShimToLegacy(wallets) {
    return {
        ...providersShimToLegacy(wallets),
        wallet: wallets.wallet,
    };
}
function walletShimFromLegacy(wallets) {
    return {
        ...providersShimFromLegacy(wallets),
        wallet: wallets.wallet,
        async getBalance() {
            return "NOT IMPLEMENTED";
        },
        address: "NOT IMPLEMENTED",
    };
}
//# sourceMappingURL=legacy-plugin.middleware.js.map