/**
 * A simple HTTP client with exponential backoff retries and 429 handling.
 */
export declare class HttpClient {
    private initialDelay;
    private maxDelay;
    private retries;
    private timeout;
    private cache;
    constructor(options?: HttpClientOptions);
    get<T>(url: string, opts?: HttpClientOptions): Promise<T>;
    private execute;
    private executeWithRetry;
}
export type HttpClientOptions = {
    initialDelay?: number;
    maxDelay?: number;
    retries?: number;
    timeout?: number;
    cache?: RequestCache;
};
export declare class HttpClientError extends Error {
    readonly status?: number;
    readonly data?: any;
    readonly headers?: Headers;
    constructor(message?: string, response?: Response, data?: any);
    /**
     * Parses the Retry-After header and returns the value in milliseconds.
     * @param maxDelay
     * @param error
     * @throws {HttpClientError} if retry-after is bigger than maxDelay.
     * @returns the retry-after value in milliseconds.
     */
    getRetryAfter(maxDelay: number, error: HttpClientError): number | undefined;
}
